@@ -128,7 +128,7 @@ static int ShowAnnotateDialog(const QString &fileName)
     return result;
 }
 
-extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
+int main(int argc, char **argv)
 {
     KLocalizedString::setApplicationDomain("cervisia");
 
